@@ -201,7 +201,7 @@ xlsx_func_binominv_handler (G_GNUC_UNUSED GnmConventions const *convs, G_GNUC_UN
 /* BINOM.INV(a,b,c) --> R.QBINOM(c,a,b) */
 {
 	GnmFunc  *f = gnm_func_lookup_or_add_placeholder ("r.qbinom");
-	GSList *arg;
+	GnmExprList *arg;
 	
 	arg = g_slist_nth (args, 2);
 	args = g_slist_remove_link (args, arg);
@@ -210,18 +210,95 @@ xlsx_func_binominv_handler (G_GNUC_UNUSED GnmConventions const *convs, G_GNUC_UN
 	return gnm_expr_new_funcall (f, args);
 }
 
+static GnmExpr const *
+xlsx_func_dist_handler (GnmExprList *args, guint n_args, char const *name, char const *name_p, char const *name_d)
+{
+	if (gnm_expr_list_length (args) != n_args) {
+		GnmFunc  *f = gnm_func_lookup_or_add_placeholder (name);
+		return gnm_expr_new_funcall (f, args);
+	} else {
+		GnmFunc  *f_if = gnm_func_lookup_or_add_placeholder ("if");
+		GnmFunc  *f_p = gnm_func_lookup_or_add_placeholder (name_p);
+		GnmFunc  *f_d = gnm_func_lookup_or_add_placeholder (name_d);
+		GnmExprList *arg_cum, *args_c;
+		GnmExpr const *cum;
+		GnmValue const *constant;
+
+		arg_cum = g_slist_nth (args, n_args - 1);
+		args = g_slist_remove_link (args, arg_cum);
+		cum = arg_cum->data;
+		gnm_expr_list_free (arg_cum);
+
+		constant = gnm_expr_get_constant (cum);
+		
+		if (constant == NULL || !VALUE_IS_NUMBER (constant)) {
+			args_c = gnm_expr_list_copy (args);
+			
+			return gnm_expr_new_funcall3 
+				(f_if, cum,
+				 gnm_expr_new_funcall (f_p, args),
+				 gnm_expr_new_funcall (f_d, args_c));
+			
+		} else if (value_is_zero (constant)) {
+			gnm_expr_free (cum);
+			return gnm_expr_new_funcall (f_d, args);
+		} else {
+			gnm_expr_free (cum);
+			return gnm_expr_new_funcall (f_p, args);
+		}
+	}
+}
+
+static GnmExpr const *
+xlsx_func_chisqdist_handler (G_GNUC_UNUSED GnmConventions const *convs, G_GNUC_UNUSED Workbook *scope, 
+			     GnmExprList *args)
+{
+	return xlsx_func_dist_handler (args, 3, "chisq.dist", "r.pchisq", "r.dchisq");
+}
+
+static GnmExpr const *
+xlsx_func_fdist_handler (G_GNUC_UNUSED GnmConventions const *convs, G_GNUC_UNUSED Workbook *scope, 
+			 GnmExprList *args)
+{
+	return xlsx_func_dist_handler (args, 4, "f.dist", "r.pf", "r.df");
+}
+
+static GnmExpr const *
+xlsx_func_lognormdist_handler (G_GNUC_UNUSED GnmConventions const *convs, G_GNUC_UNUSED Workbook *scope, 
+			       GnmExprList *args)
+{
+	return xlsx_func_dist_handler (args, 4, "lognorm.dist", "r.plnorm", "r.dlnorm");
+}
+
+static GnmExpr const *
+xlsx_func_negbinomdist_handler (G_GNUC_UNUSED GnmConventions const *convs, G_GNUC_UNUSED Workbook *scope, 
+				GnmExprList *args)
+{
+	return xlsx_func_dist_handler (args, 4, "negbinom.dist", "r.pnbinom", "r.dnbinom");
+}
 
 static void
-xlsx_write_r_q_func (GnmConventionsOut *out, char const *name, GnmExprConstPtr const *ptr, int n,
+xlsx_write_r_q_func (GnmConventionsOut *out, char const *name, char const *name_rt, 
+		     GnmExprConstPtr const *ptr, int n, int n_p,
 		     gboolean use_lower_tail, gboolean use_log)
 {
-	/* R.Qx(a,a_1,...,a_n) --> name(mod(a),a_1,...,a_n) */
+	/* R.Qx(a_0,...,a_n_p,...,a_n) --> name(a_0,...,mod(a_n_p),...a_n) */
 	GString *target = out->accum;
 	int i;
 
-	g_string_append (target, name);
+	if (name_rt != NULL && !use_lower_tail) {
+		use_lower_tail = TRUE;
+		g_string_append (target, name_rt);
+	} else
+		g_string_append (target, name);
+		
 	g_string_append_c (target, '(');
 	
+	for (i = 1; i<=n_p; i++) {
+		gnm_expr_as_gstring (ptr[i], out);
+		g_string_append_c (target, ',');
+	}
+
 	if (!use_lower_tail)
 			g_string_append (target, "1-");
 	if (use_log) {
@@ -231,17 +308,31 @@ xlsx_write_r_q_func (GnmConventionsOut *out, char const *name, GnmExprConstPtr c
 	} else
 		gnm_expr_as_gstring (ptr[0], out);
 
-	g_string_append_c (target, ',');
-	for (i = 1; i<=n; i++) {
-		gnm_expr_as_gstring (ptr[i], out);
-		if (i < n)
-			g_string_append_c (target, ',');
+	if (n > n_p) {
+		g_string_append_c (target, ',');
+		for (i = n_p+1; i<=n; i++) {
+			gnm_expr_as_gstring (ptr[i], out);
+			if (i < n)
+				g_string_append_c (target, ',');
+		}
 	}
 	g_string_append_c (target, ')');
 }
 
+/**
+ * xlsx_func_r_q_output_handler:
+ *
+ * @out: #GnmConventionsOut
+ * @func: #GnmExprFunction 
+ * @n: last index used for a parameter
+ * @n_p: index of the probability argument, usually 0 
+ * @name:
+ *
+ * Print the appropriate simple function call
+ */
 static gboolean
-xlsx_func_r_q_output_handler (GnmConventionsOut *out, GnmExprFunction const *func, int n, char const *name)
+xlsx_func_r_q_output_handler (GnmConventionsOut *out, GnmExprFunction const *func, int n, int n_p, 
+			      char const *name, char const *name_rt)
 {
 	GnmExprConstPtr const *ptr = func->argv;
 	GString *target = out->accum;
@@ -267,25 +358,25 @@ xlsx_func_r_q_output_handler (GnmConventionsOut *out, GnmExprFunction const *fun
 			use_log = value_is_zero (constant) ? 0 : 1;
 	} else
 		use_log = 0;
-	
+
 	if (use_lower_tail < 2 && use_log == 0) {
 		/* R.Qx(a,b,c) --> name(a,b,c) */		
 		/* R.Qx(a,b,c) --> name(1-a,b,c) */
-		xlsx_write_r_q_func (out,name, ptr, n, use_lower_tail, 0);
+		xlsx_write_r_q_func (out, name, name_rt, ptr, n, n_p, use_lower_tail, 0);
 		return TRUE;
 	} else if (use_lower_tail < 2 && use_log == 1) {
 		/* R.Qx(a,b,c) --> name(exp(a),b,c) */
 		/* R.Qx(a,b,c) --> name(1-exp(a),b,c) */
-		xlsx_write_r_q_func (out,name, ptr, n, use_lower_tail, 1);
+		xlsx_write_r_q_func (out, name, name_rt, ptr, n, n_p, use_lower_tail, 1);
 		return TRUE;
 	} else if (/* use_lower_tail == 2 && */ use_log == 0) {
 		/* R.Qx(a,b,c,d) --> if(d,name(a,b,c), name(1-a,b,c)) */
 		g_string_append (target, "if(");
 		gnm_expr_as_gstring (ptr[n+1], out);
 		g_string_append_c (target, ',');
-		xlsx_write_r_q_func (out,name, ptr, n, 1, 0);
+		xlsx_write_r_q_func (out, name, name_rt, ptr, n, n_p, 1, 0);
 		g_string_append_c (target, ',');
-		xlsx_write_r_q_func (out,name, ptr, n, 0, 0);
+		xlsx_write_r_q_func (out, name, name_rt, ptr, n, n_p, 0, 0);
 		g_string_append_c (target, ')');
 		return TRUE;
 	} else if (use_lower_tail < 2 /* && use_log == 2 */) {
@@ -296,9 +387,9 @@ xlsx_func_r_q_output_handler (GnmConventionsOut *out, GnmExprFunction const *fun
 		g_string_append (target, "if(");
 		gnm_expr_as_gstring (ptr[n+2], out);
 		g_string_append_c (target, ',');
-		xlsx_write_r_q_func (out,name, ptr, n, use_lower_tail, 1);
+		xlsx_write_r_q_func (out, name, name_rt, ptr, n, n_p, use_lower_tail, 1);
 		g_string_append_c (target, ',');
-		xlsx_write_r_q_func (out,name, ptr, n, use_lower_tail, 0);
+		xlsx_write_r_q_func (out, name, name_rt, ptr, n, n_p, use_lower_tail, 0);
 		g_string_append_c (target, ')');
 		return TRUE;
 	} else /*if (use_lower_tail == 2 && use_log == 2 */ {
@@ -310,15 +401,15 @@ xlsx_func_r_q_output_handler (GnmConventionsOut *out, GnmExprFunction const *fun
 		g_string_append (target, ",if(");
 		gnm_expr_as_gstring (ptr[n+2], out);
 		g_string_append_c (target, ',');
-		xlsx_write_r_q_func (out,name, ptr, n, 1, 1);
+		xlsx_write_r_q_func (out, name, name_rt, ptr, n, n_p, 1, 1);
 		g_string_append_c (target, ',');
-		xlsx_write_r_q_func (out,name, ptr, n, 1, 0);
+		xlsx_write_r_q_func (out, name, name_rt, ptr, n, n_p, 1, 0);
 		g_string_append (target, "),if(");
 		gnm_expr_as_gstring (ptr[n+2], out);
 		g_string_append_c (target, ',');
-		xlsx_write_r_q_func (out,name, ptr, n, 0, 1);
+		xlsx_write_r_q_func (out, name, name_rt, ptr, n, n_p, 0, 1);
 		g_string_append_c (target, ',');
-		xlsx_write_r_q_func (out,name, ptr, n, 0, 0);
+		xlsx_write_r_q_func (out, name, name_rt, ptr, n, n_p, 0, 0);
 		g_string_append (target, "))");
 		return TRUE;
 	}
@@ -327,126 +418,49 @@ xlsx_func_r_q_output_handler (GnmConventionsOut *out, GnmExprFunction const *fun
 static gboolean
 xlsx_func_norminv_output_handler (GnmConventionsOut *out, GnmExprFunction const *func)
 {
-	return xlsx_func_r_q_output_handler (out, func, 2, "_xlfn.NORM.INV");
+	return xlsx_func_r_q_output_handler (out, func, 2, 0, "_xlfn.NORM.INV", NULL);
 }
 
 static gboolean
 xlsx_func_chisqinv_output_handler (GnmConventionsOut *out, GnmExprFunction const *func)
 {
-	return xlsx_func_r_q_output_handler (out, func, 1, "_xlfn.CHISQ.INV");
+	return xlsx_func_r_q_output_handler (out, func, 1, 0, "_xlfn.CHISQ.INV", "_xlfn.CHISQ.INV.RT");
 }
 
 static gboolean
 xlsx_func_finv_output_handler (GnmConventionsOut *out, GnmExprFunction const *func)
 {
-	return xlsx_func_r_q_output_handler (out, func, 2, "_xlfn.F.INV");
+	return xlsx_func_r_q_output_handler (out, func, 2, 0, "_xlfn.F.INV", "_xlfn.F.INV.RT");
 }
 
 static gboolean
 xlsx_func_binominv_output_handler (GnmConventionsOut *out, GnmExprFunction const *func)
 {
-#define OUTPUT_BINOM_INV(pre,post)		g_string_append (target, "_xlfn.BINOM.INV("); \
-		gnm_expr_as_gstring (ptr[1], out);\
-		g_string_append_c (target, ',');\
-		gnm_expr_as_gstring (ptr[2], out);\
-		g_string_append (target, pre);\
-		gnm_expr_as_gstring (ptr[0], out);\
-		g_string_append (target, post)
+	return xlsx_func_r_q_output_handler (out, func, 2, 2, "_xlfn.BINOM.INV", NULL);
+}
 
-	GnmExprConstPtr const *ptr = func->argv;
-	GString *target = out->accum;
+static gboolean
+xlsx_func_betainv_output_handler (GnmConventionsOut *out, GnmExprFunction const *func)
+{
+	return xlsx_func_r_q_output_handler (out, func, 2, 0, "_xlfn.BETA.INV", NULL);
+}
 
-	int use_lower_tail; /* 0: never; 1: always; 2: sometimes */
-	int use_log;        /* 0: never; 1: always; 2: sometimes */
+static gboolean
+xlsx_func_gammainv_output_handler (GnmConventionsOut *out, GnmExprFunction const *func)
+{
+	return xlsx_func_r_q_output_handler (out, func, 2, 0, "_xlfn.GAMMA.INV", NULL);
+}
 
-	if (func->argc < 3 || func->argc > 5)
-		return FALSE;
+static gboolean
+xlsx_func_lognorminv_output_handler (GnmConventionsOut *out, GnmExprFunction const *func)
+{
+	return xlsx_func_r_q_output_handler (out, func, 2, 0, "_xlfn.LOGNORM.INV", NULL);
+}
 
-	if (func->argc > 3) {
-		GnmValue const *constant = gnm_expr_get_constant (ptr[3]);
-		if (constant == NULL || !VALUE_IS_NUMBER (constant))
-			use_lower_tail = 2;
-		else
-			use_lower_tail = value_is_zero (constant) ? 0 : 1;
-	} else
-		use_lower_tail = 1;
-	if (func->argc > 4) {
-		GnmValue const *constant = gnm_expr_get_constant (ptr[4]);
-		if (constant == NULL || !VALUE_IS_NUMBER (constant))
-			use_log = 2;
-		else 
-			use_log = value_is_zero (constant) ? 0 : 1;
-	} else
-		use_log = 0;
-
-	if (use_lower_tail == 1 && use_log == 0) {
-		/* R.QBINOM(c,a,b) --> BINOM.INV(a,b,c) */
-		OUTPUT_BINOM_INV (",",")");
-		return TRUE;
-	} else if (use_lower_tail == 0 && use_log == 0) {
-		/* R.QBINOM(c,a,b) --> BINOM.INV(a,b,1-c) */
-		OUTPUT_BINOM_INV (",1-",")");
-		return TRUE;
-	} else if (/* use_lower_tail == 2 && */ use_log == 0) {
-		/* R.QBINOM(c,a,b,d) --> if(d,binom.inv(a,b,c), binom.inv(a,b,1-c)) */
-		g_string_append (target, "if(");
-		gnm_expr_as_gstring (ptr[3], out);
-		g_string_append (target, ",");
-		OUTPUT_BINOM_INV(",","),");
-		OUTPUT_BINOM_INV(",1-","))");
-		return TRUE;
-	} else if (use_lower_tail == 1 && use_log == 1) {
-		/* R.QBINOM(c,a,b) --> BINOM.INV(a,b,exp(c)) */
-		OUTPUT_BINOM_INV (",exp(","))");
-		return TRUE;
-	} else if (use_lower_tail == 0 && use_log == 1) {
-		/* R.QBINOM(c,a,b) --> BINOM.INV(a,b,1-exp(c)) */
-		OUTPUT_BINOM_INV (",1-exp(","))");
-		return TRUE;
-	} else if (/* use_lower_tail == 2 && */ use_log == 1) {
-		/* R.QBINOM(c,a,b,d) --> if(d,binom.inv(a,b,exp(c)), binom.inv(a,b,1-exp(c))) */
-		g_string_append (target, "if(");
-		gnm_expr_as_gstring (ptr[3], out);
-		g_string_append (target, ",");
-		OUTPUT_BINOM_INV(",exp(",")),");
-		OUTPUT_BINOM_INV(",1-exp(",")))");
-		return TRUE;
-	} else if (use_lower_tail == 0 /* && use_log == 2 */) {
-		/* R.QBINOM(c,a,b,d,e) -->
-                               if(e,binom.inv(a,b,1-exp(c)),binom.inv(a,b,1-c))*/
-		g_string_append (target, "if(");
-		gnm_expr_as_gstring (ptr[4], out);
-		g_string_append (target, ",");
-		OUTPUT_BINOM_INV(",1-exp(",")),");
-		OUTPUT_BINOM_INV(",1-","))");
-		return TRUE;
-	} else if (use_lower_tail == 1 /* && use_log == 2 */) {
-		/* R.QBINOM(c,a,b,d,e) -->
-                          if(e,binom.inv(a,b,exp(c)),binom.inv(a,b,c))*/
-		g_string_append (target, "if(");
-		gnm_expr_as_gstring (ptr[4], out);
-		g_string_append (target, ",");
-		OUTPUT_BINOM_INV(",exp(",")),");
-		OUTPUT_BINOM_INV(",","))");
-		return TRUE;
-	} else /*if (use_lower_tail == 2 && use_log == 2 */ {
-		/* R.QBINOM(c,a,b,d,e) -->
-                          if(d,if(e,binom.inv(a,b,exp(c)),binom.inv(a,b,c)),
-                               if(e,binom.inv(a,b,1-exp(c)),binom.inv(a,b,1-c)))*/
-		g_string_append (target, "if(");
-		gnm_expr_as_gstring (ptr[3], out);
-		g_string_append (target, ",if(");
-		gnm_expr_as_gstring (ptr[4], out);
-		g_string_append (target, ",");
-		OUTPUT_BINOM_INV(",exp(",")),");
-		OUTPUT_BINOM_INV(",",")),if(");
-		gnm_expr_as_gstring (ptr[4], out);
-		g_string_append (target, ",");
-		OUTPUT_BINOM_INV(",1-exp(",")),");
-		OUTPUT_BINOM_INV(",1-",")))");
-		return TRUE;
-	}
-#undef OUTPUT_BINOM_INV
+static gboolean
+xlsx_func_tinv_output_handler (GnmConventionsOut *out, GnmExprFunction const *func)
+{
+	return xlsx_func_r_q_output_handler (out, func, 1, 0, "_xlfn.T.INV", NULL);
 }
 
 static gboolean
@@ -464,6 +478,18 @@ xlsx_func_floor_output_handler (GnmConventionsOut *out, GnmExprFunction const *f
 	return FALSE;
 }
 
+static gboolean
+xlsx_func_erf_output_handler (GnmConventionsOut *out, GnmExprFunction const *func)
+{
+	/* func->argc == 1 is handled by the translation */
+	if (func->argc != 1) {
+		g_string_append (out->accum, "ERF");
+		gnm_expr_list_as_string (func->argc, func->argv, out);
+		return TRUE;
+	}
+	return FALSE;
+}
+
 
 GnmConventions *
 xlsx_conventions_new (gboolean output)
@@ -473,6 +499,10 @@ xlsx_conventions_new (gboolean output)
 		gpointer handler;
 	} const xlfn_func_handlers[] = {
 		{"BINOM.INV", xlsx_func_binominv_handler},
+		{"CHISQ.DIST", xlsx_func_chisqdist_handler},
+		{"F.DIST", xlsx_func_fdist_handler},
+		{"NEGBINOM.DIST", xlsx_func_negbinomdist_handler},
+		{"LOGNORM.DIST", xlsx_func_lognormdist_handler},
 		{NULL, NULL}
 	};
 
@@ -480,10 +510,15 @@ xlsx_conventions_new (gboolean output)
 		char const *gnm_name;
 		gpointer handler;
 	} const xlfn_func_output_handlers[] = {
+		{"R.QBETA", xlsx_func_betainv_output_handler},
 		{"R.QBINOM", xlsx_func_binominv_output_handler},
 		{"R.QCHISQ", xlsx_func_chisqinv_output_handler},
-		{"R.QNORM", xlsx_func_norminv_output_handler},
 		{"R.QF", xlsx_func_finv_output_handler},
+		{"R.QGAMMA", xlsx_func_gammainv_output_handler},
+		{"R.QLNORM", xlsx_func_lognorminv_output_handler},
+		{"R.QNORM", xlsx_func_norminv_output_handler},
+		{"R.QT", xlsx_func_tinv_output_handler},
+		{"ERF", xlsx_func_erf_output_handler},
 		{"FLOOR", xlsx_func_floor_output_handler},
 		{NULL, NULL}
 	};
@@ -501,6 +536,8 @@ xlsx_conventions_new (gboolean output)
 		{ "CHISQ.TEST", "CHITEST" },
 		{ "CONFIDENCE.NORM", "CONFIDENCE" },
 		{ "COVARIANCE.P", "COVAR" },
+		{ "ERF.PRECISE", "ERF" },
+		{ "ERFC.PRECISE", "ERFC" },
 		{ "EXPON.DIST", "EXPONDIST" },
 		{ "F.DIST.RT", "FDIST" },
 		{ "F.INV", "R.QF" }, /* see output handler */
@@ -508,7 +545,9 @@ xlsx_conventions_new (gboolean output)
 		{ "F.TEST", "FTEST" },
 		{ "GAMMA.DIST", "GAMMADIST" },
 		{ "GAMMA.INV", "GAMMAINV" },
+		{ "HYPGEOM.DIST", "HYPGEOMDIST" },
 		{ "LOGNORM.INV", "LOGINV" },
+		{ "MODE.SNGL", "MODE" },
 		{ "NORM.DIST", "NORMDIST" },
 		{ "NORM.INV", "NORMINV" },
 		{ "NORM.S.INV", "NORMSINV" },
