@@ -68,11 +68,8 @@ value_new_complex (complex_t const *c, char imunit)
 		return value_new_error_NUM (NULL);
 	else if (complex_real_p (c))
 		return value_new_float (c->re);
-	else {
-		char f[5 + 4 * sizeof (int) + sizeof (GNM_FORMAT_g)];
-		sprintf (f, "%%.%d" GNM_FORMAT_g, GNM_DIG);
-		return value_new_string_nocopy (complex_to_string (c, f, f, imunit));
-	}
+	else
+		return value_new_string_nocopy (complex_to_string (c, imunit));
 }
 
 /***************************************************************************/
@@ -127,7 +124,7 @@ gnumeric_imaginary (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	        return value_new_float (0.0);
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	return value_new_float (c.im);
 }
@@ -151,7 +148,7 @@ gnumeric_imabs (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	return value_new_float (complex_mod (&c));
 }
@@ -178,7 +175,7 @@ gnumeric_imreal (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 		return value_dup (argv[0]);
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	return value_new_float (c.re);
 }
@@ -202,7 +199,7 @@ gnumeric_imconjugate (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	complex_conj (&res, &c);
 	return value_new_complex (&res, imunit);
@@ -225,7 +222,7 @@ gnumeric_iminv (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_inverse (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -248,7 +245,7 @@ gnumeric_imneg (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_negative (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -274,7 +271,7 @@ gnumeric_imcos (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	complex_cos (&res, &c);
 	return value_new_complex (&res, imunit);
@@ -300,7 +297,7 @@ gnumeric_imtan (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	complex_tan (&res, &c);
 	return value_new_complex (&res, imunit);
@@ -326,7 +323,7 @@ gnumeric_imsec (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	complex_cos (&res, &c);
 	gsl_complex_inverse (&res, &res);
@@ -352,7 +349,7 @@ gnumeric_imcsc (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	complex_sin (&res, &c);
 	gsl_complex_inverse (&res, &res);
@@ -379,7 +376,7 @@ gnumeric_imcot (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	complex_tan (&res, &c);
 	gsl_complex_inverse (&res, &res);
@@ -407,7 +404,7 @@ gnumeric_imexp (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	complex_exp (&res, &c);
 	return value_new_complex (&res, imunit);
@@ -432,7 +429,7 @@ gnumeric_imargument (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	return value_new_float (complex_angle (&c));
 }
@@ -459,7 +456,7 @@ gnumeric_imln (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	complex_ln (&res, &c);
 	return value_new_complex (&res, imunit);
@@ -485,7 +482,7 @@ gnumeric_imlog2 (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	complex_ln (&res, &c);
 	complex_scale_real (&res, 1 / M_LN2gnum);
@@ -511,7 +508,7 @@ gnumeric_imlog10 (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	complex_ln (&res, &c);
 	complex_scale_real (&res, 1 / M_LN10gnum);
@@ -538,17 +535,17 @@ gnumeric_impower (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &a, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	if (value_get_as_complex (argv[1], &b, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	if (complex_zero_p (&a) && complex_zero_p (&b))
 		return value_new_error_DIV0 (ei->pos);
 
 	complex_pow (&res, &a, &b);
 	if (complex_invalid_p (&res))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	return value_new_complex (&res, imunit);
 }
@@ -574,10 +571,10 @@ gnumeric_imdiv (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &a, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	if (value_get_as_complex (argv[1], &b, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	if (complex_zero_p (&b))
 		return value_new_error_DIV0 (ei->pos);
@@ -605,7 +602,7 @@ gnumeric_imsin (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	complex_sin (&res, &c);
 	return value_new_complex (&res, imunit);
@@ -629,7 +626,7 @@ gnumeric_imsinh (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_sinh (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -654,7 +651,7 @@ gnumeric_imcosh (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_cosh (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -679,7 +676,7 @@ gnumeric_imtanh (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_tanh (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -703,7 +700,7 @@ gnumeric_imsech (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_sech (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -728,7 +725,7 @@ gnumeric_imcsch (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_csch (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -752,7 +749,7 @@ gnumeric_imcoth (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_coth (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -779,7 +776,7 @@ gnumeric_imarcsin (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_arcsin (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -806,7 +803,7 @@ gnumeric_imarccos (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_arccos (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -833,7 +830,7 @@ gnumeric_imarctan (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_arctan (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -857,7 +854,7 @@ gnumeric_imarcsec (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_arcsec (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -882,7 +879,7 @@ gnumeric_imarccsc (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_arccsc (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -906,7 +903,7 @@ gnumeric_imarccot (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_arccot (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -933,7 +930,7 @@ gnumeric_imarcsinh (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_arcsinh (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -961,7 +958,7 @@ gnumeric_imarccosh (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_arccosh (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -989,7 +986,7 @@ gnumeric_imarctanh (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_arctanh (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -1013,7 +1010,7 @@ gnumeric_imarcsech (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_arcsech (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -1038,7 +1035,7 @@ gnumeric_imarccsch (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_arccsch (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -1063,7 +1060,7 @@ gnumeric_imarccoth (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char      imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	gsl_complex_arccoth (&c, &res);
 	return value_new_complex (&res, imunit);
@@ -1089,7 +1086,7 @@ gnumeric_imsqrt (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	complex_sqrt (&res, &c);
 	return value_new_complex (&res, imunit);
@@ -1116,10 +1113,10 @@ gnumeric_imsub (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &a, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	if (value_get_as_complex (argv[1], &b, &imunit))
-		return value_new_error_VALUE (ei->pos);
+		return value_new_error_NUM (ei->pos);
 
 	complex_sub (&res, &a, &b);
 	return value_new_complex (&res, imunit);
@@ -1158,7 +1155,7 @@ callback_function_imoper (GnmEvalPos const *ep, GnmValue const *value, void *clo
 
 	imptr = VALUE_IS_NUMBER (value) ? &dummy : &result->imunit;
 	if (value_get_as_complex (value, &c, imptr))
-		return value_new_error_VALUE (ep);
+		return value_new_error_NUM (ep);
 
 	switch (result->type) {
 	case Improduct:
