@@ -1851,81 +1851,81 @@ gnumeric_get_link (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 
 GnmFuncDescriptor const info_functions[] = {
 	{ "cell",	"sr",  help_cell,
-	  gnumeric_cell, NULL, NULL, NULL, NULL,
+	  gnumeric_cell, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_SUBSET_WITH_EXTENSIONS, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "error.type",	"E",  help_error_type,
-	  gnumeric_error_type, NULL, NULL, NULL, NULL,
+	  gnumeric_error_type, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "info",	"s",  help_info,
-	  gnumeric_info, NULL, NULL, NULL, NULL,
+	  gnumeric_info, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "isblank",	"E",  help_isblank,
-	  gnumeric_isblank, NULL, NULL, NULL, NULL,
+	  gnumeric_isblank, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "iserr",	"E",    help_iserr,
-	  gnumeric_iserr, NULL, NULL, NULL, NULL,
+	  gnumeric_iserr, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "iserror",	"E",    help_iserror,
-	  gnumeric_iserror, NULL, NULL, NULL, NULL,
+	  gnumeric_iserror, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "iseven",	"f",  help_iseven,
-	  gnumeric_iseven, NULL, NULL, NULL, NULL,
+	  gnumeric_iseven, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "islogical",	"E",  help_islogical,
-	  gnumeric_islogical, NULL, NULL, NULL, NULL,
+	  gnumeric_islogical, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "isna",	"E",    help_isna,
-	  gnumeric_isna, NULL, NULL, NULL, NULL,
+	  gnumeric_isna, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "isnontext",	"E",  help_isnontext,
-	  gnumeric_isnontext, NULL, NULL, NULL, NULL,
+	  gnumeric_isnontext, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "isnumber",	"E",  help_isnumber,
-	  gnumeric_isnumber, NULL, NULL, NULL, NULL,
+	  gnumeric_isnumber, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "isodd",	"S",  help_isodd,
-	  gnumeric_isodd, NULL, NULL, NULL, NULL,
+	  gnumeric_isodd, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "isref",	NULL,  help_isref,
-	  NULL, gnumeric_isref, NULL, NULL, NULL,
+	  NULL, gnumeric_isref, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "istext",	"E",  help_istext,
-	  gnumeric_istext, NULL, NULL, NULL, NULL,
+	  gnumeric_istext, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "n",		"S",  help_n,
-	  gnumeric_n, NULL, NULL, NULL, NULL,
+	  gnumeric_n, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "na",		"", help_na,
-	  gnumeric_na, NULL, NULL, NULL, NULL,
+	  gnumeric_na, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "type",	"?",  help_type,
-	  gnumeric_type, NULL, NULL, NULL, NULL,
+	  gnumeric_type, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
 /* XL stores this in statistical ? */
         { "countblank",	"r",   help_countblank,
-	  gnumeric_countblank, NULL, NULL, NULL, NULL,
+	  gnumeric_countblank, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
 	{ "error",	"s",   help_error,
-	  gnumeric_error, NULL, NULL, NULL, NULL,
+	  gnumeric_error, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 
 	{ "expression",	"r",    help_expression,
-	  gnumeric_expression, NULL, NULL, NULL, NULL,
+	  gnumeric_expression, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 /* XLM : looks common in charts */
 	{ "get.formula", "r",    help_get_formula,
-	  gnumeric_get_formula, NULL, NULL, NULL, NULL,
+	  gnumeric_get_formula, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "get.link", "r",    help_get_link,
-	  gnumeric_get_link, NULL, NULL, NULL, NULL,
+	  gnumeric_get_link, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "isformula", "r",    help_isformula,
-	  gnumeric_isformula, NULL, NULL, NULL, NULL,
+	  gnumeric_isformula, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE},
 	{ "getenv",	"s",  help_getenv,
-	  gnumeric_getenv, NULL, NULL, NULL, NULL,
+	  gnumeric_getenv, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 
         {NULL}
