@@ -1,6 +1,8 @@
 #include <gnumeric-config.h>
 #include "gnumeric.h"
 #include <mathfunc.h>
+#include <sf-trig.h>
+#include <sf-gamma.h>
 #include "extra.h"
 
 #define ML_ERR_return_NAN { return gnm_nan; }
@@ -34,6 +36,10 @@ qcauchy (gnm_float p, gnm_float location, gnm_float scale,
 		else
 			p = gnm_exp (p);
 	}
+	if (p > 0.5) {
+		p = 1 - p;
+		lower_tail = !lower_tail;
+	}
 	if (lower_tail) scale = -scale;
 	return location + scale / gnm_tan(M_PIgnum * p);
 }
@@ -132,6 +138,12 @@ qsnorm (gnm_float p, gnm_float shape, gnm_float location, gnm_float scale,
 	if (shape == 0.)
 		return qnorm (p, location, scale, lower_tail, log_p);
 
+	if (!log_p && p > 0.9) {
+		/* We're far into the tail.  Flip.  */
+		p = 1 - p;
+		lower_tail = !lower_tail;
+	}
+
 	x0 = 0.0;
 	params[0] = shape;
 	params[1] = location;
@@ -289,6 +301,12 @@ qst (gnm_float p, gnm_float n, gnm_float shape,
 	if (shape == 0.)
 		return qt (p, n, lower_tail, log_p);
 
+	if (!log_p && p > 0.9) {
+		/* We're far into the tail.  Flip.  */
+		p = 1 - p;
+		lower_tail = !lower_tail;
+	}
+
 	x0 = 0.0;
 	params[0] = n;
 	params[1] = shape;
