@@ -347,6 +347,8 @@ callback_function_collect (GnmEvalPos const *ep, GnmValue const *value,
 	case VALUE_ERROR:
 		if (cl->flags & COLLECT_IGNORE_ERRORS)
 			ignore = TRUE;
+		else if (cl->flags & COLLECT_ZERO_ERRORS)
+			x = 0;
 		else
 			return value_new_error_VALUE (ep);
 		break;
@@ -435,6 +437,7 @@ collect_floats (int argc, GnmExprConstPtr const *argv,
 	CellIterFlags iter_flags = CELL_ITER_ALL;
 	GnmValue *key = NULL;
 	CollectFlags keyflags = flags & ~COLLECT_ORDER_IRRELEVANT;
+	gboolean strict;
 
 	if (constp)
 		*constp = FALSE;
@@ -477,7 +480,10 @@ collect_floats (int argc, GnmExprConstPtr const *argv,
 	/* ---------------------------------------- */
 
 	if (flags & COLLECT_IGNORE_SUBTOTAL)
-		iter_flags |= CELL_ITER_IGNORE_SUBTOTAL;
+		iter_flags |= (CELL_ITER_IGNORE_SUBTOTAL |
+			       CELL_ITER_IGNORE_FILTERED);
+
+	strict = (flags & (COLLECT_IGNORE_ERRORS | COLLECT_ZERO_ERRORS)) == 0;
 
 	cl.alloc_count = 0;
 	cl.data = NULL;
@@ -489,7 +495,7 @@ collect_floats (int argc, GnmExprConstPtr const *argv,
 	*error = function_iterate_argument_values
 		(ep, &callback_function_collect, &cl,
 		 argc, argv,
-		 TRUE, iter_flags);
+		 strict, iter_flags);
 	if (*error) {
 		g_assert (VALUE_IS_ERROR (*error));
 		g_free (cl.data);
@@ -596,7 +602,7 @@ collect_floats_value_with_info (GnmValue const *val, GnmEvalPos const *ep,
 
 /**
  * float_range_function:
- * @arcg:
+ * @argc:
  * @argv:
  * @ei:
  * @func: (scope call):
@@ -860,8 +866,8 @@ collect_float_pairs (GnmValue const *vx, GnmValue const *vy,
 
 /**
  * float_range_function2d:
- * @arcg:
- * @argv:
+ * @val0:
+ * @val1:
  * @ei:
  * @func: (scope call):
  * @flags:
@@ -905,8 +911,8 @@ float_range_function2d (GnmValue const *val0, GnmValue const *val1,
 
 /**
  * float_range_function2:
- * @arcg:
- * @argv:
+ * @val0:
+ * @val1:
  * @ei:
  * @func: (scope call):
  * @flags:
@@ -986,17 +992,26 @@ collect_strings (int argc, GnmExprConstPtr const *argv,
 {
 	collect_strings_t cl;
 	CellIterFlags iter_flags = CELL_ITER_ALL;
+	gboolean strict;
+
+	/* We don't handle these flags */
+	g_return_val_if_fail (!(flags & COLLECT_ZERO_ERRORS), NULL);
+	g_return_val_if_fail (!(flags & COLLECT_ZERO_STRINGS), NULL);
+	g_return_val_if_fail (!(flags & COLLECT_ZEROONE_BOOLS), NULL);
+	g_return_val_if_fail (!(flags & COLLECT_ZERO_BLANKS), NULL);
 
 	if (flags & COLLECT_IGNORE_BLANKS)
 		iter_flags = CELL_ITER_IGNORE_BLANK;
 
+	strict = (flags & (COLLECT_IGNORE_ERRORS | COLLECT_ZERO_ERRORS)) == 0;
+
 	cl.data = g_ptr_array_new ();
 	cl.flags = flags;
 
 	*error = function_iterate_argument_values
 		(ep, &callback_function_collect_strings, &cl,
 		 argc, argv,
-		 TRUE, iter_flags);
+		 strict, iter_flags);
 	if (*error) {
 		g_assert (VALUE_IS_ERROR (*error));
 		collect_strings_free (cl.data);
