@@ -932,9 +932,15 @@ link_range_dep (GnmDepContainer *deps, GnmDependent *dep,
 		DependencyRange const *r)
 {
 	int i = BUCKET_OF_ROW (r->range.start.row);
-	int const end = BUCKET_OF_ROW (r->range.end.row);
+	int end = BUCKET_OF_ROW (r->range.end.row);
 	DependencyRange r2 = *r;
 
+	/*
+	 * It is possible to see ranges bigger than the sheet when
+	 * operating with 3D ranges.  See bug #704109.
+	 */
+	end = MIN (end, deps->buckets - 1);
+
 	for ( ; i <= end; i++) {
 		DependencyRange *result;
 
@@ -968,12 +974,14 @@ unlink_range_dep (GnmDepContainer *deps, GnmDependent *dep,
 		  DependencyRange const *r)
 {
 	int i = BUCKET_OF_ROW (r->range.start.row);
-	int const end = BUCKET_OF_ROW (r->range.end.row);
+	int end = BUCKET_OF_ROW (r->range.end.row);
 	DependencyRange r2 = *r;
 
 	if (!deps)
 		return;
 
+	end = MIN (end, deps->buckets - 1);
+
 	for ( ; i <= end; i++) {
 		DependencyRange *result;
 
@@ -1175,16 +1183,15 @@ workbook_unlink_3d_dep (GnmDependent *dep)
  * @sheet:
  * @texpr:
  * @r:
- *
- * Returns: (element-type GnmDependent) (transfer full):
+ * @accum: (inout) (transfer full) (element-type GnmDependent):
  **/
-GSList *
+void
 gnm_dep_style_dependency (Sheet *sheet,
 			  GnmExprTop const *texpr,
-			  GnmRange const *r)
+			  GnmRange const *r,
+			  GPtrArray *accum)
 {
 	int row, col;
-	GSList *res = NULL;
 
 	/*
 	 * FIXME: Maybe do better for an expression that is just an
@@ -1204,11 +1211,9 @@ gnm_dep_style_dependency (Sheet *sheet,
 
 			dependent_set_expr (dep, texpr);
 			dependent_link (dep);
-			res = g_slist_prepend (res, dep);
+			g_ptr_array_add (accum, dep);
 		}
 	}
-
-	return res;
 }
 
 /*****************************************************************************/
@@ -2389,6 +2394,7 @@ dep_hash_destroy (GHashTable *hash, GSList **dyn_deps, Sheet *sheet)
 					 gnm_dep_set_expr_undo_new (dep));
 			dependent_set_expr (dep, newtree);
 			gnm_expr_top_unref (newtree);
+			dependent_link (dep);
 		}
 	}
 	g_slist_free (deplist);
