@@ -111,9 +111,10 @@ void dependents_workbook_destroy  (Workbook *wb);
 void dependents_revive_sheet      (Sheet *sheet);
 void workbook_queue_all_recalc	  (Workbook *wb);
 
-GSList *gnm_dep_style_dependency (Sheet *sheet,
-				  GnmExprTop const *texpr,
-				  GnmRange const *r);
+void gnm_dep_style_dependency (Sheet *sheet,
+			       GnmExprTop const *texpr,
+			       GnmRange const *r,
+			       GPtrArray *accum);
 
 GnmDepContainer *gnm_dep_container_new  (Sheet *sheet);
 void		 gnm_dep_container_dump	(GnmDepContainer const *deps,
