@@ -45,6 +45,7 @@
 #include <mstyle.h>
 #include <application.h>
 #include <validation.h>
+#include <input-msg.h>
 #include <workbook.h>
 #include <wbc-gtk.h>
 #include <commands.h>
@@ -212,9 +213,6 @@ typedef struct _FormatState {
 		GtkWindow *w;
 		gpointer closure;
 	} style_selector;
-
-	void (*dialog_changed) (gpointer user_data);
-	gpointer	dialog_changed_user_data;
 } FormatState;
 
 enum {
@@ -235,19 +233,19 @@ enum {
 static void
 fmt_dialog_changed (FormatState *state)
 {
+	GOFormatSel *gfs;
+	GOFormat const *fmt;
+	gboolean ok;
+	
 	if (!state->enable_edit)
 		return;
-
-	if (state->dialog_changed)
-		state->dialog_changed (state->dialog_changed_user_data);
-	else {
-		GOFormatSel *gfs = GO_FORMAT_SEL (state->format_sel);
-		GOFormat const *fmt = go_format_sel_get_fmt (gfs);
-		gboolean ok = !go_format_is_invalid (fmt);
-
-		gtk_widget_set_sensitive (state->apply_button, ok);
-		gtk_widget_set_sensitive (state->ok_button, ok);
-	}
+	
+	gfs = GO_FORMAT_SEL (state->format_sel);
+	fmt = go_format_sel_get_fmt (gfs);
+	ok = !go_format_is_invalid (fmt);
+	
+	gtk_widget_set_sensitive (state->apply_button, ok);
+	gtk_widget_set_sensitive (state->ok_button, ok);
 }
 
 /* Default to the 'Format' page but remember which page we were on between
@@ -1785,7 +1783,8 @@ static void
 cb_validation_changed (G_GNUC_UNUSED GtkEntry *ignored,
 		       FormatState *state)
 {
-	state->validation.changed = TRUE;
+	if (state->enable_edit)
+		state->validation.changed = TRUE;
 }
 
 static void
@@ -1800,11 +1799,10 @@ fmt_dialog_init_validation_expr_entry (FormatState *state, ExprEntry *entry,
 	gnumeric_editable_enters (
 		GTK_WINDOW (state->dialog),
 		GTK_WIDGET (entry->entry));
+	gnm_expr_entry_set_flags (entry->entry, GNM_EE_FORCE_ABS_REF | GNM_EE_SHEET_OPTIONAL, GNM_EE_MASK);
 	g_signal_connect (G_OBJECT (entry->entry),
 		"changed",
 		G_CALLBACK (cb_validation_changed), state);
-	gnm_expr_entry_set_flags (entry->entry, GNM_EE_FORCE_ABS_REF | GNM_EE_SHEET_OPTIONAL, GNM_EE_MASK);
-
 }
 
 static void
@@ -1936,7 +1934,6 @@ fmt_dialog_init_validation_page (FormatState *state)
 	if (0 == (state->conflicts & (1 << MSTYLE_VALIDATION)))
 		v = gnm_style_get_validation (state->style);
 	if (v != NULL) {
-		GnmValidation const *v = gnm_style_get_validation (state->style);
 		GnmParsePos pp;
 
 		gtk_combo_box_set_active (state->validation.error.action, v->style);
@@ -1965,6 +1962,26 @@ fmt_dialog_init_validation_page (FormatState *state)
 
 /*****************************************************************************/
 
+static void
+input_msg_rebuild_input_msg (FormatState *state)
+{
+	GnmInputMsg *im;
+	char *msg = gnumeric_textview_get_text (state->input_msg.msg);
+	char const *title = gtk_entry_get_text (state->input_msg.title);
+
+	im = gnm_input_msg_new	(msg, title);
+	g_free (msg);
+	gnm_style_set_input_msg (state->result, im);
+	fmt_dialog_changed (state);
+}
+
+static void
+cb_input_msg_rebuild (G_GNUC_UNUSED void *ignored,
+		      FormatState *state)
+{
+	input_msg_rebuild_input_msg (state);
+}
+
 static void
 cb_input_msg_flag_toggled (GtkToggleButton *button, FormatState *state)
 {
@@ -1974,21 +1991,22 @@ cb_input_msg_flag_toggled (GtkToggleButton *button, FormatState *state)
 	gtk_widget_set_sensitive (GTK_WIDGET (state->input_msg.msg_label), flag);
 	gtk_widget_set_sensitive (GTK_WIDGET (state->input_msg.title), flag);
 	gtk_widget_set_sensitive (GTK_WIDGET (state->input_msg.msg), flag);
+
+	if (state->enable_edit) {
+		if (flag)
+			input_msg_rebuild_input_msg (state);
+		else
+			gnm_style_set_input_msg (state->result, NULL);
+		fmt_dialog_changed (state);
+	}
 }
 
 static void
 fmt_dialog_init_input_msg_page (FormatState *state)
 {
-	g_return_if_fail (state != NULL);
+	GnmInputMsg const *im = NULL;
 
-	/*
-	 * NOTE: This should be removed when the feature
-	 * is implemented.
-	 */
-#if 1L
-	gtk_notebook_remove_page (state->notebook, 7);
-	return;
-#endif
+	g_return_if_fail (state != NULL);
 
 	/* Setup widgets */
 	state->input_msg.flag        = GTK_TOGGLE_BUTTON (go_gtk_builder_get_widget (state->gui, "input_msg_flag"));
@@ -1997,16 +2015,30 @@ fmt_dialog_init_input_msg_page (FormatState *state)
 	state->input_msg.title       = GTK_ENTRY         (go_gtk_builder_get_widget (state->gui, "input_msg_title"));
 	state->input_msg.msg         = GTK_TEXT_VIEW     (go_gtk_builder_get_widget (state->gui, "input_msg_msg"));
 
+	/* Initialize */
+	if (0 == (state->conflicts & (1 << MSTYLE_INPUT_MSG)))
+		im = gnm_style_get_input_msg (state->style);
+	if (im) {
+		gtk_entry_set_text (state->input_msg.title,
+				    gnm_input_msg_get_title (im));
+		gnumeric_textview_set_text (state->input_msg.msg,
+					    gnm_input_msg_get_msg (im));
+	}
+	gtk_toggle_button_set_active (state->input_msg.flag, im != NULL);
+
 	gnumeric_editable_enters (
 		GTK_WINDOW (state->dialog),
 		GTK_WIDGET (state->input_msg.title));
-	gnumeric_editable_enters (
-		GTK_WINDOW (state->dialog),
-		GTK_WIDGET (state->input_msg.msg));
 
 	g_signal_connect (G_OBJECT (state->input_msg.flag),
 		"toggled",
 		G_CALLBACK (cb_input_msg_flag_toggled), state);
+	g_signal_connect (G_OBJECT (state->input_msg.title),
+		"changed",
+		G_CALLBACK (cb_input_msg_rebuild), state);
+	g_signal_connect (G_OBJECT (gtk_text_view_get_buffer (state->input_msg.msg)),
+		"changed",
+		G_CALLBACK (cb_input_msg_rebuild), state);
 
 	/* Initialize */
 	cb_input_msg_flag_toggled (state->input_msg.flag, state);
@@ -2178,7 +2210,7 @@ set_initial_focus (FormatState *s)
 }
 
 static void
-fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
+fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno, gint pages)
 {
 	static struct {
 		char const *const name;
@@ -2398,6 +2430,7 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 		GNUMERIC_HELP_LINK_CELL_FORMAT);
 
 	state->ok_button = go_gtk_builder_get_widget (state->gui, "okbutton");
+	gtk_widget_set_sensitive (state->ok_button, FALSE);
 	g_signal_connect (G_OBJECT (state->ok_button),
 		"clicked",
 		G_CALLBACK (cb_fmt_dialog_dialog_buttons), state);
@@ -2440,6 +2473,15 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 	g_signal_connect (G_OBJECT (dialog), "destroy",
 			  G_CALLBACK (cb_dialog_destroy), NULL);
 
+	if (pages > 0)
+		for (i = 0; i <= FD_LAST; i++) {
+			GtkWidget *widget = gtk_notebook_get_nth_page
+				(state->notebook, i);
+			if (widget != NULL && !((1<<i) & pages))
+				gtk_widget_hide (widget);
+		}
+
+
 	gnumeric_restore_window_geometry (GTK_WINDOW (state->dialog),
 					  CELL_FORMAT_KEY);
 }
@@ -2538,8 +2580,6 @@ dialog_cell_format_init (WBCGtk *wbcg)
 	state->style		= NULL;
 	state->result		= gnm_style_new ();
 	state->selection_mask	= 0;
-	state->dialog_changed	= NULL;
-	state->dialog_changed_user_data = NULL;
 
 	(void) sv_selection_foreach (state->sv,
 		fmt_dialog_selection_type, state);
@@ -2549,7 +2589,7 @@ dialog_cell_format_init (WBCGtk *wbcg)
 }
 
 void
-dialog_cell_format (WBCGtk *wbcg, FormatDialogPosition_t pageno)
+dialog_cell_format (WBCGtk *wbcg, FormatDialogPosition_t pageno, gint pages)
 {
 	FormatState  *state;
 
@@ -2564,7 +2604,13 @@ dialog_cell_format (WBCGtk *wbcg, FormatDialogPosition_t pageno)
 	state->style_selector.w = NULL;
 	state->style_selector.closure = NULL;
 
-	fmt_dialog_impl (state, pageno);
+	if (pages == 0) {
+		int i;
+		for (i = FD_NUMBER; i <= FD_PROTECTION; i++)
+			pages |= (1 << i); 
+	}
+
+	fmt_dialog_impl (state, pageno, pages);
 
 	wbc_gtk_attach_guru (state->wbcg, GTK_WIDGET (state->dialog));
 	go_gtk_nonmodal_dialog (wbcg_toplevel (state->wbcg),
@@ -2589,7 +2635,6 @@ dialog_cell_format_select_style (WBCGtk *wbcg, gint pages,
 				 GnmStyle *style, gpointer closure)
 {
 	FormatState  *state;
-	gint i;
 
 	g_return_val_if_fail (wbcg != NULL, NULL);
 	state = dialog_cell_format_init (wbcg);
@@ -2606,14 +2651,7 @@ dialog_cell_format_select_style (WBCGtk *wbcg, gint pages,
 		state->conflicts = 0;
 	}
 
-	fmt_dialog_impl (state, FD_BACKGROUND);
-
-	for (i = 0; i <= FD_LAST; i++) {
-		GtkWidget *widget = gtk_notebook_get_nth_page
-			(state->notebook, i);
-		if (widget != NULL && !((1<<i) & pages))
-			gtk_widget_hide (widget);
-	}
+	fmt_dialog_impl (state, FD_BACKGROUND, pages);
 
 	gtk_widget_hide (state->apply_button);
 
