@@ -466,13 +466,13 @@ cb_pm_dialog_free (PluginManagerGUI *pm_gui)
 	}
 
 	if (pm_gui->gui != NULL)
-		g_object_unref (G_OBJECT (pm_gui->gui));
+		g_object_unref (pm_gui->gui);
 	if (pm_gui->model_plugins != NULL)
-		g_object_unref (G_OBJECT (pm_gui->model_plugins));
+		g_object_unref (pm_gui->model_plugins);
 	if (pm_gui->model_details != NULL)
-		g_object_unref (G_OBJECT (pm_gui->model_details));
+		g_object_unref (pm_gui->model_details);
 	if (pm_gui->model_directories != NULL)
-		g_object_unref (G_OBJECT (pm_gui->model_directories));
+		g_object_unref (pm_gui->model_directories);
 	g_free (pm_gui);
 }
 
@@ -644,7 +644,6 @@ dialog_plugin_manager (WBCGtk *wbcg)
 	GtkBuilder *gui;
 	GtkWidget *scrolled;
 	GtkWidget *scrolled_directories;
-	GtkWidget *hbox;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *rend;
 	GtkWidget *image = NULL;
@@ -729,13 +728,12 @@ dialog_plugin_manager (WBCGtk *wbcg)
 	gtk_container_add (GTK_CONTAINER (scrolled), GTK_WIDGET (pm_gui->view_details));
 
 	pm_gui->frame_mark_for_deactivation =
-		go_gtk_builder_get_widget (gui, "frame_mark_for_deactivation");
+		go_gtk_builder_get_widget (gui, "mark-for-deactivation-grid");
 	pm_gui->checkbutton_mark_for_deactivation =
 		go_gtk_builder_get_widget (gui, "checkbutton_mark_for_deactivation");
 
 	/* Set-up directories page */
 
-	hbox = go_gtk_builder_get_widget (gui, "directory-box");
 	pm_gui->model_directories = gtk_list_store_new (DIR_NUM_COLMNS, G_TYPE_STRING,
 							G_TYPE_BOOLEAN);
 	pm_gui->list_directories = GTK_TREE_VIEW (
