@@ -409,8 +409,8 @@ static void
 margin_preview_page_available_size (PrinterSetupState *state,
 				    MarginPreviewPageAvailableSize *available_size)
 {
-	GList *child_list;
-	GtkWidget *child_widget, *grid;
+	GList *children, *l;
+	GtkWidget *grid;
 	unsigned *widths, *heights;
 	GtkRequisition requisition;
 	unsigned top, left, width, height, i;
@@ -432,10 +432,9 @@ margin_preview_page_available_size (PrinterSetupState *state,
 	heights = g_new0 (guint, nrows);
 
 	/* Iterate through all child widgets in the grid */
-	for (child_list = gtk_container_get_children (GTK_CONTAINER (grid));
-	     child_list; child_list = child_list->next) {
-
-		child_widget = child_list->data;
+	children = gtk_container_get_children (GTK_CONTAINER (grid));
+	for (l = children; l; l = l->next) {
+		GtkWidget *child_widget = l->data;
 
 		/* Determine which cells the align widget spans across */
 		gtk_container_child_get (GTK_CONTAINER (grid), GTK_WIDGET (child_widget),
@@ -466,6 +465,7 @@ margin_preview_page_available_size (PrinterSetupState *state,
 			}
 		}
 	}
+	g_list_free (children);
 
 	/* Calculate width of container widget using maximum */
 	/* widget widths from above */
@@ -2313,8 +2313,8 @@ do_setup_page_info (PrinterSetupState *state)
 							 (GTK_COMBO_BOX (state->comment_display.combo)));
 	do_setup_comment_display (state);
 
-	state->icon_rd = gnumeric_load_image ("right-down.png");
-	state->icon_dr = gnumeric_load_image ("down-right.png");
+	state->icon_rd = gnumeric_load_image ("res:gnm:pixmaps/right-down.png");
+	state->icon_dr = gnumeric_load_image ("res:gnm:pixmaps/down-right.png");
 
 	gtk_widget_hide (state->icon_dr);
 	gtk_widget_hide (state->icon_rd);
