@@ -86,7 +86,9 @@ calc_char_index (RenderData_t *renderdata, int col, int *dx)
 	GtkCellRenderer *cell =	stf_preview_get_cell_renderer (renderdata, col);
 	PangoLayout *layout;
 	PangoFontDescription *font_desc;
-	int ci, width;
+	int ci, width, padx;
+
+	gtk_cell_renderer_get_padding (cell, &padx, NULL);
 
 	g_object_get (G_OBJECT (cell), "font_desc", &font_desc, NULL);
 	layout = gtk_widget_create_pango_layout (GTK_WIDGET (renderdata->tree_view), "x");
@@ -96,7 +98,7 @@ calc_char_index (RenderData_t *renderdata, int col, int *dx)
 	pango_font_description_free (font_desc);
 
 	if (width < 1) width = 1;
-	ci = (*dx < 0) ? 0 : (*dx + width / 2) / width;
+	ci = (*dx < padx) ? 0 : (*dx - padx + width / 2) / width;
 	*dx -= ci * width;
 
 	return ci;
@@ -368,7 +370,7 @@ cb_col_key_press (GtkWidget *button,
 
 /**
  * fixed_page_update_preview
- * @pagedata : mother struct
+ * @pagedata: mother struct
  *
  * Will simply update the preview
  *
@@ -458,7 +460,7 @@ fixed_page_auto_clicked (G_GNUC_UNUSED GtkButton *button,
 
 /**
  * stf_dialog_fixed_page_prepare
- * @data : mother struct
+ * @data: mother struct
  *
  * Will prepare the fixed page
  *
@@ -522,8 +524,14 @@ cb_treeview_motion (GtkWidget *widget,
 
 	if (col >= 0 && col < renderdata->colcount) {
 		int ci = calc_char_index (renderdata, col, &dx);
-		if (ci <= colwidth)
-			pagedata->fixed.ruler_x = x - dx - 1;
+		if (ci <= colwidth) {
+			int padx;
+			GtkCellRenderer *cell =
+				stf_preview_get_cell_renderer (renderdata, col);
+
+			gtk_cell_renderer_get_padding (cell, &padx, NULL);
+			pagedata->fixed.ruler_x = x - dx + padx;
+		}
 	}
 
 	gdk_event_request_motions (event);
@@ -547,6 +555,8 @@ cb_treeview_draw (GtkWidget *widget,
 	int height;
 	GtkAllocation a;
 	GdkWindow *bin_window;
+	GdkRGBA ruler_color;
+	GtkStyleContext *context;
 
 	if (ruler_x < 0)
 		return FALSE;
@@ -558,10 +568,17 @@ cb_treeview_draw (GtkWidget *widget,
 	gtk_widget_get_allocation (widget, &a);
 	height = a.height;
 
+	context = gtk_widget_get_style_context (GTK_WIDGET (pagedata->dialog));
+	gtk_style_context_save (context);
+	gtk_style_context_add_region (context, "fixed-format-ruler", 0);
+	gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL,
+				     &ruler_color);
+	gtk_style_context_restore (context);
+
 	cairo_save (cr);
 	cairo_rectangle (cr, ruler_x, 0, ruler_x + 1, height);
 	cairo_clip (cr);
-	cairo_set_source_rgb (cr, 1.0, 0, 0);
+	gdk_cairo_set_source_rgba (cr, &ruler_color);
 	cairo_move_to (cr, ruler_x, 0);
 	cairo_line_to (cr, ruler_x, height);
 	cairo_stroke (cr);
@@ -570,28 +587,13 @@ cb_treeview_draw (GtkWidget *widget,
 	return FALSE;
 }
 
-static gboolean
-cb_treeview_draw_2 (GtkWidget *widget,
-		    cairo_t *cr,
-		    StfDialogData *pagedata)
-{
-  /* Manually call default handler */
-  GTK_WIDGET_GET_CLASS (widget)->draw (widget, cr);
-
-  /* Call the would-be connect_after handler.  */
-  cb_treeview_draw (widget, cr, pagedata);
-
-  /* Abort emmission.  */
-  return TRUE;
-}
-
 /*************************************************************************************************
  * FIXED EXPORTED FUNCTIONS
  *************************************************************************************************/
 
 /**
  * stf_dialog_fixed_page_cleanup
- * @pagedata : mother struct
+ * @pagedata: mother struct
  *
  * Will cleanup fixed page run-time data
  *
@@ -635,14 +637,8 @@ stf_dialog_fixed_page_init (GtkBuilder *gui, StfDialogData *pagedata)
 	g_signal_connect (G_OBJECT (renderdata->tree_view),
 		"motion_notify_event",
 		 G_CALLBACK (cb_treeview_motion), pagedata);
-#if 0
-	/* Needs GtkTreeView bugfix in gtk+ of 20110914.  */
+
 	g_signal_connect_after (G_OBJECT (renderdata->tree_view),
 		"draw",
 		 G_CALLBACK (cb_treeview_draw), pagedata);
-#else
-	g_signal_connect (G_OBJECT (renderdata->tree_view),
-		"draw",
-		 G_CALLBACK (cb_treeview_draw_2), pagedata);
-#endif
 }
