@@ -114,7 +114,7 @@ static void
 cb_view_destroy (ViewState *state)
 {
 	if (state->gui != NULL) {
-		g_object_unref (G_OBJECT (state->gui));
+		g_object_unref (state->gui);
 		state->gui = NULL;
 	}
 
