@@ -89,7 +89,7 @@ static void
 cb_attr_dialog_dialog_destroy (AttrState *state)
 {
 	if (state->gui != NULL) {
-		g_object_unref (G_OBJECT (state->gui));
+		g_object_unref (state->gui);
 		state->gui = NULL;
 	}
 
