@@ -1732,14 +1732,13 @@ free_values (GnmValue **values, int top)
 /**
  * function_call_with_exprs:
  * @ei: EvalInfo containing valid fn_def!
- * @flags:
  *
  * Do the guts of calling a function.
  *
  * Returns the result.
  **/
 GnmValue *
-function_call_with_exprs (GnmFuncEvalInfo *ei, GnmExprEvalFlags flags)
+function_call_with_exprs (GnmFuncEvalInfo *ei)
 {
 	GnmFunc const *fn_def;
 	int	  i, iter_count, iter_width = 0, iter_height = 0;
@@ -1748,10 +1747,13 @@ function_call_with_exprs (GnmFuncEvalInfo *ei, GnmExprEvalFlags flags)
 	int	 *iter_item = NULL;
 	int argc;
 	GnmExprConstPtr *argv;
+	GnmExprEvalFlags flags, pass_flags;
 
 	g_return_val_if_fail (ei != NULL, NULL);
 	g_return_val_if_fail (ei->func_call != NULL, NULL);
 
+	flags = ei->flags;
+
 	argc = ei->func_call->argc;
 	argv = ei->func_call->argv;
 	fn_def = ei->func_call->func;
@@ -1777,6 +1779,9 @@ function_call_with_exprs (GnmFuncEvalInfo *ei, GnmExprEvalFlags flags)
 	    iter_count == -1)
 		return gnumeric_if2 (ei, argc, argv, flags);
 
+	pass_flags = (flags &
+		      (GNM_EXPR_EVAL_ARRAY_CONTEXT));
+
 	for (i = 0; i < argc; i++) {
 		char arg_type = fn_def->fn.args.arg_types[i];
 		/* expr is always non-null, missing args are encoded as
@@ -1786,6 +1791,7 @@ function_call_with_exprs (GnmFuncEvalInfo *ei, GnmExprEvalFlags flags)
 		if (arg_type == 'A' || arg_type == 'r') {
 			tmp = args[i] = gnm_expr_eval
 				(expr, ei->pos,
+				 pass_flags |
 				 GNM_EXPR_EVAL_PERMIT_NON_SCALAR |
 				 GNM_EXPR_EVAL_WANT_REF);
 			if (VALUE_IS_ERROR (tmp)) {
@@ -1809,10 +1815,13 @@ function_call_with_exprs (GnmFuncEvalInfo *ei, GnmExprEvalFlags flags)
 		}
 
 		/* force scalars whenever we are certain */
-		tmp = args[i] = gnm_expr_eval (expr, ei->pos,
-		       ((iter_count >= 0 || arg_type == '?')
-			       ? (GNM_EXPR_EVAL_PERMIT_EMPTY | GNM_EXPR_EVAL_PERMIT_NON_SCALAR)
-			       : (GNM_EXPR_EVAL_PERMIT_EMPTY)));
+		tmp = args[i] = gnm_expr_eval
+			(expr, ei->pos,
+			 pass_flags |
+			 GNM_EXPR_EVAL_PERMIT_EMPTY |
+			 (iter_count >= 0 || arg_type == '?'
+			  ? GNM_EXPR_EVAL_PERMIT_NON_SCALAR
+			  : 0));
 
 		if (arg_type == '?')	/* '?' arguments are unrestriced */
 			continue;
