@@ -28,7 +28,7 @@ struct _GnmPane {
 	/* Sliding scroll */
 	GnmPaneSlideHandler slide_handler;
 	gpointer   slide_data;
-	int        sliding;	/* a gtk_timeout tag, -1 means not set */
+	guint      sliding_timer;	/* a gtk_timeout tag, 0 means not set */
 	int        sliding_x, sliding_y;
 	int        sliding_dx, sliding_dy;
 	gboolean   sliding_adjacent_h, sliding_adjacent_v;
@@ -44,7 +44,7 @@ struct _GnmPane {
 	int		 index;
 	struct {
 		GocCanvas *canvas;
-		ItemBar   *item;
+		GnmItemBar *item;
 	} col, row;
 
 	/* Lines across the grid.  Used for col/row resize and the creation of
@@ -54,11 +54,11 @@ struct _GnmPane {
 		GocPoint  *points;
 	} size_guide;
 
-	ItemGrid      *grid;
-	ItemEdit      *editor;
+	GnmItemGrid *grid;
+	GnmItemEdit *editor;
 
 	struct {
-		ItemCursor *std, *rangesel, *special;
+		GnmItemCursor *std, *rangesel, *special;
 		GSList *animated;
 
 		GSList *expr_range;	/* highlight refs while editing */
