@@ -454,8 +454,8 @@ kill_popup_menu (G_GNUC_UNUSED GtkWidget *widget, GtkMenu *menu)
 
 /**
  * gnumeric_popup_menu :
- * @menu : #GtkMenu
- * @event : #GdkEventButton optionally NULL
+ * @menu: #GtkMenu
+ * @event: #GdkEventButton optionally NULL
  *
  * Bring up a popup and if @event is non-NULL ensure that the popup is on the
  * right screen.
@@ -485,52 +485,17 @@ gnumeric_popup_menu (GtkMenu *menu, GdkEventButton *event)
 			: gtk_get_current_event_time());
 }
 
-void
+static void
 gnumeric_tooltip_set_style (GtkWidget *widget)
 {
-	int i;
-	for (i = 0; i < 5 ; i++) {
-		gtk_widget_override_color (widget, i, &gs_black);
-		gtk_widget_override_background_color (widget, i, &gs_yellow);
-	}
-}
-
-/**
- * gnumeric_create_tooltip_text_view_widget:
- *
- * Returns: (transfer full): the newly allocated #GtkWidget.
- **/
-GtkWidget *
-gnumeric_create_tooltip_text_view_widget (void)
-{
-	GtkWidget *label, *frame;
-
-	frame = gtk_frame_new (NULL);
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
-	label = gtk_text_view_new ();
-
-	gtk_container_add (GTK_CONTAINER (frame), label);
-
-	return label;
-}
-
-/**
- * gnumeric_create_tooltip_widget:
- *
- * Returns: (transfer full): the newly allocated #GtkWidget.
- **/
-GtkWidget *
-gnumeric_create_tooltip_widget (void)
-{
-	GtkWidget *label, *frame;
-
-	frame = gtk_frame_new (NULL);
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
-	label = gtk_label_new ("");
-
-	gtk_container_add (GTK_CONTAINER (frame), label);
-
-	return label;
+	gtk_style_context_add_class (gtk_widget_get_style_context (widget),
+				     GTK_STYLE_CLASS_TOOLTIP);
+	gtk_style_context_add_class (gtk_widget_get_style_context (widget),
+				     "pseudo-tooltip");
+	if (GTK_IS_CONTAINER (widget))
+		gtk_container_forall (GTK_CONTAINER (widget),
+				      (GtkCallback) (gnumeric_tooltip_set_style),
+				      NULL);
 }
 
 /**
@@ -544,21 +509,23 @@ GtkWidget *
 gnumeric_convert_to_tooltip (GtkWidget *ref_widget, GtkWidget *widget)
 {
 	GtkWidget *tip, *frame;
+	GdkScreen *screen = gtk_widget_get_screen (ref_widget);
 
 	tip = gtk_window_new (GTK_WINDOW_POPUP);
 	gtk_window_set_type_hint (GTK_WINDOW (tip),
 				  GDK_WINDOW_TYPE_HINT_TOOLTIP);
 	gtk_window_set_resizable (GTK_WINDOW (tip), FALSE);
 	gtk_window_set_gravity (GTK_WINDOW (tip), GDK_GRAVITY_NORTH_WEST);
-	gtk_window_set_screen (GTK_WINDOW (tip), gtk_widget_get_screen (ref_widget));
-	gtk_widget_set_name (tip, "gnumeric-tooltip");
-
-	frame = gtk_widget_get_toplevel (widget);
+	gtk_window_set_screen (GTK_WINDOW (tip), screen);
+	gtk_widget_set_name (tip, "gtk-tooltip");
 
+	frame = gtk_frame_new (NULL);
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+	gtk_widget_show (frame);
+	gtk_container_add (GTK_CONTAINER (frame), widget);
 	gtk_container_add (GTK_CONTAINER (tip), frame);
 
 	gnumeric_tooltip_set_style (tip);
-	gnumeric_tooltip_set_style (widget);
 
 	return widget;
 }
@@ -571,7 +538,7 @@ gnumeric_convert_to_tooltip (GtkWidget *ref_widget, GtkWidget *widget)
 GtkWidget *
 gnumeric_create_tooltip (GtkWidget *ref_widget)
 {
-	return gnumeric_convert_to_tooltip (ref_widget, gnumeric_create_tooltip_widget ());
+	return gnumeric_convert_to_tooltip (ref_widget, gtk_label_new (""));
 }
 
 void
@@ -991,14 +958,13 @@ int_to_entry (GtkEntry *entry, gint the_int)
 GtkWidget *
 gnumeric_load_image (char const *filename)
 {
-	char *path = g_build_filename (gnm_icon_dir (), filename, NULL);
-	GtkWidget *image = gtk_image_new_from_file (path);
-	g_free (path);
-
-	if (image)
-		gtk_widget_show (image);
-
-	return image;
+	GdkPixbuf *pixbuf = gnumeric_load_pixbuf (filename);
+	if (pixbuf) {
+		GtkWidget *image = gtk_image_new_from_pixbuf (pixbuf);
+		g_object_unref (pixbuf);
+		return image;
+	}
+	return NULL;
 }
 
 /**
@@ -1012,10 +978,15 @@ gnumeric_load_image (char const *filename)
 GdkPixbuf *
 gnumeric_load_pixbuf (char const *filename)
 {
-	char *path = g_build_filename (gnm_icon_dir (), filename, NULL);
-	GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file (path, NULL);
-	g_free (path);
-	return pixbuf;
+	if (strncmp (filename, "res:", 4) == 0 ||
+	    g_path_is_absolute (filename))
+		return go_gdk_pixbuf_load_from_file (filename);
+	else {
+		char *path = g_build_filename (gnm_icon_dir (), filename, NULL);
+		GdkPixbuf *pixbuf = go_gdk_pixbuf_load_from_file (path);
+		g_free (path);
+		return pixbuf;
+	}
 }
 
 
