@@ -8,7 +8,7 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n-lib.h>
+#include "gnm-i18n.h"
 #include "gnumeric.h"
 #include "item-bar.h"
 #include "gnm-pane-impl.h"
@@ -144,6 +144,7 @@ ib_reload_style (GnmItemBar *ib)
 		ib->selection_fonts[ui] =
 			pango_context_load_font (pcontext, desc);
 		pango_layout_set_font_description (layout, desc);
+		pango_font_description_free (desc);
 		pango_layout_get_extents (layout, &ink_rect, NULL);
 		ib->selection_font_ascents[ui] =
 			PANGO_PIXELS (ink_rect.height + ink_rect.y);
@@ -1163,15 +1164,17 @@ gnm_item_bar_class_init (GObjectClass  *gobject_klass)
 	gobject_klass->dispose = item_bar_dispose;
 	gobject_klass->set_property = item_bar_set_property;
 	g_object_class_install_property (gobject_klass, GNM_ITEM_BAR_PROP_PANE,
-		g_param_spec_object ("pane", "pane",
-			"The pane containing the associated grid",
-			GNM_PANE_TYPE,
-			GSF_PARAM_STATIC | G_PARAM_WRITABLE));
+		g_param_spec_object ("pane",
+				     P_("Pane"),
+				     P_("The pane containing the associated grid"),
+				     GNM_PANE_TYPE,
+				     GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 	g_object_class_install_property (gobject_klass, GNM_ITEM_BAR_PROP_IS_COL_HEADER,
-		g_param_spec_boolean ("IsColHeader", "IsColHeader",
-			"Is the item-bar a header for columns or rows",
-			FALSE,
-			GSF_PARAM_STATIC | G_PARAM_WRITABLE));
+		g_param_spec_boolean ("IsColHeader",
+				      P_("IsColHeader"),
+				      P_("Is the item-bar a header for columns or rows"),
+				      FALSE,
+				      GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 
 	item_klass->realize     = item_bar_realize;
 	item_klass->unrealize   = item_bar_unrealize;
