@@ -839,7 +839,8 @@ plain_draw : /* a quick hack to deal with 142267 */
 			ig_cairo_draw_bound (ig, cr, 1, start_y, 1, y);
 	}
 
-	gtk_widget_destroy (entry);
+	g_object_ref_sink (entry);
+	g_object_unref (entry);
 
 	g_slist_free (merged_used);	   /* merges with bottom in view */
 	g_slist_free (merged_active_seen); /* merges with bottom the view */
@@ -963,22 +964,26 @@ item_grid_button_pressed (GocItem *item, int button, double x_, double y_)
 	if (button == 1 && !sheet_selection_is_allowed (sheet, &pos))
 		return TRUE;
 
-	/* button 1 will always change the selection,  the other buttons will
+	/* Button == 1 is used to trigger hyperlinks (and possibly similar */
+	/* special cases. Otherwise button == 2 should behave exactly like */
+	/* button == 1. See bug #700792                                    */
+	
+	/* buttons 1 and 2 will always change the selection,  the other buttons will
 	 * only effect things if the target is not already selected.  */
 	already_selected = sv_is_pos_selected (sv, pos.col, pos.row);
-	if (button == 1 || !already_selected) {
+	if (button == 1 || button == 2 || !already_selected) {
 		if (!(event->state & (GDK_CONTROL_MASK|GDK_SHIFT_MASK)))
 			sv_selection_reset (sv);
 
-		if (event->button != 1 || !(event->state & GDK_SHIFT_MASK) ||
+		if ((event->button != 1 && event->button != 2) 
+		    || !(event->state & GDK_SHIFT_MASK) ||
 		    sv->selections == NULL) {
 			sv_selection_add_pos (sv, pos.col, pos.row,
 					      (already_selected && (event->state & GDK_CONTROL_MASK)) ?
 					      GNM_SELECTION_MODE_REMOVE :
 					      GNM_SELECTION_MODE_ADD);
 			sv_make_cell_visible (sv, pos.col, pos.row, FALSE);
-		} else if (event->button != 2)
-			sv_selection_extend_to (sv, pos.col, pos.row);
+		} else sv_selection_extend_to (sv, pos.col, pos.row);
 		sheet_update (sheet);
 	}
 
@@ -986,7 +991,8 @@ item_grid_button_pressed (GocItem *item, int button, double x_, double y_)
 		return TRUE;  /* we already ignored the button release */
 
 	switch (button) {
-	case 1: {
+	case 1:
+	case 2: {
 		guint32 double_click_time;
 
 		/*
@@ -1013,8 +1019,6 @@ item_grid_button_pressed (GocItem *item, int button, double x_, double y_)
 		break;
 	}
 
-	case 2: break;
-
 	case 3: scg_context_menu (scg, event, FALSE, FALSE);
 		break;
 	default :
@@ -1072,8 +1076,8 @@ cb_cursor_come_to_rest (GnmItemGrid *ig)
 			gnm_canvas_get_position (canvas, &wx, &wy,
 						 ig->last_x, ig->last_y);
 			ig->tip = gnumeric_create_tooltip (cw);
-			gnumeric_position_tooltip (ig->tip, wx, wy, TRUE);
 			gtk_label_set_text (GTK_LABEL (ig->tip), tiptext);
+			gnumeric_position_tooltip (ig->tip, wx, wy, TRUE);
 			gtk_widget_show_all (gtk_widget_get_toplevel (ig->tip));
 		}
 	}
@@ -1128,7 +1132,7 @@ item_grid_button_released (GocItem *item, int button, G_GNUC_UNUSED double x_, G
 	ItemGridSelectionType selecting = ig->selecting;
 	GdkEventButton *event = (GdkEventButton *) goc_canvas_get_cur_event (item->canvas);
 
-	if (button != 1)
+	if (button != 1 && button != 2)
 		return FALSE;
 
 	gnm_pane_slide_stop (pane);
@@ -1160,7 +1164,7 @@ item_grid_button_released (GocItem *item, int button, G_GNUC_UNUSED double x_, G
 		gnm_expr_entry_signal_update (
 			wbcg_get_entry_logical (scg_wbcg (scg)), TRUE);
 
-	if (selecting == GNM_ITEM_GRID_SELECTING_CELL_RANGE) {
+	if (selecting == GNM_ITEM_GRID_SELECTING_CELL_RANGE && button == 1) {
 		GnmCellPos const *pos = sv_is_singleton_selected (scg_view (scg));
 		if (pos != NULL) {
 			GnmHLink *link;
@@ -1244,14 +1248,16 @@ gnm_item_grid_class_init (GObjectClass *gobject_klass)
 	gobject_klass->finalize     = item_grid_finalize;
 	gobject_klass->set_property = item_grid_set_property;
 	g_object_class_install_property (gobject_klass, GNM_ITEM_GRID_PROP_SHEET_CONTROL_GUI,
-		g_param_spec_object ("SheetControlGUI", "SheetControlGUI",
-			"the sheet control gui controlling the item",
-			SHEET_CONTROL_GUI_TYPE,
-                        GSF_PARAM_STATIC | G_PARAM_WRITABLE));
+		g_param_spec_object ("SheetControlGUI",
+				     P_("SheetControlGUI"),
+				     P_("The sheet control gui controlling the item"),
+				     SHEET_CONTROL_GUI_TYPE,
+				     GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 	g_object_class_install_property (gobject_klass, GNM_ITEM_GRID_PROP_BOUND,
-		g_param_spec_pointer ("bound", "Bound",
-			"The display bounds",
-			GSF_PARAM_STATIC | G_PARAM_WRITABLE));
+		g_param_spec_pointer ("bound",
+				      P_("Bound"),
+				      P_("The display bounds"),
+				      GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 
 	item_klass->realize     = item_grid_realize;
 	item_klass->unrealize     = item_grid_unrealize;
