@@ -7,48 +7,32 @@
 
 G_BEGIN_DECLS
 
-/* WARNING : Any preprocessor conditionals in here must also be placed in libspreadsheet-config.h */
-#ifdef HAVE_IEEEFP_H
-#include <ieeefp.h>
-#endif
-#ifdef HAVE_IEEE754_H
-#include <ieee754.h>
-#endif
+/*
+ * WARNING: Any preprocessor conditionals in here must also be placed
+ * in gnumeric-features.h.in
+ */
 
-#ifndef HAVE_LGAMMA
-/* Defined in mathfunc.c  */
+#ifdef GNM_SUPPLIES_LGAMMA
 GO_VAR_DECL int signgam;
 double lgamma (double x);
 #endif
-#ifndef HAVE_LGAMMA_R
-/* Defined in mathfunc.c  */
+
+#ifdef GNM_SUPPLIES_LGAMMA_R
 double lgamma_r (double x, int *signp);
 #endif
 
 #ifdef GNM_WITH_LONG_DOUBLE
 
-#ifdef HAVE_SUNMATH_H
-#include <sunmath.h>
+#ifdef GNM_SUPPLIES_ERFL
+long double erfl (long double x);
+#endif
+
+#ifdef GNM_SUPPLIES_ERFCL
+long double erfl (long double x);
 #endif
 
 typedef long double gnm_float;
 
-#ifdef HAVE_ERFL
-#define gnm_erf erfl
-#else
-#define NEED_FAKE_ERFGNUM
-/* Defined in mathfunc.c  */
-gnm_float gnm_erf (gnm_float x);
-#endif
-
-#ifdef HAVE_ERFCL
-#define gnm_erfc erfcl
-#else
-#define NEED_FAKE_ERFCGNUM
-/* Defined in mathfunc.c  */
-gnm_float gnm_erfc (gnm_float x);
-#endif
-
 #define gnm_abs fabsl
 #define gnm_acos acosl
 #define gnm_acosh acoshl
@@ -59,8 +43,9 @@ gnm_float gnm_erfc (gnm_float x);
 #define gnm_atan2 atan2l
 #define gnm_atanh atanhl
 #define gnm_ceil ceill
-#define gnm_cos cosl
 #define gnm_cosh coshl
+#define gnm_erf erfl
+#define gnm_erfc erfcl
 #define gnm_exp expl
 #define gnm_expm1 expm1l
 #define gnm_fake_ceil go_fake_ceill
@@ -89,13 +74,16 @@ gnm_float gnm_erfc (gnm_float x);
 #define gnm_pow10 go_pow10l
 #define gnm_pow2 go_pow2l
 #define gnm_render_general go_render_generall
-#define gnm_sin sinl
 #define gnm_sinh sinhl
 #define gnm_sqrt sqrtl
 #define gnm_strto go_strtold
 #define gnm_sub_epsilon go_sub_epsilonl
-#define gnm_tan tanl
 #define gnm_tanh tanhl
+#ifndef GNM_REDUCES_TRIG_RANGE
+#define gnm_sin sinl
+#define gnm_cos cosl
+#define gnm_tan tanl
+#endif
 
 #define GNM_FORMAT_e	"Le"
 #define GNM_FORMAT_E	"LE"
@@ -118,9 +106,19 @@ gnm_float gnm_erfc (gnm_float x);
 #define gnm_quad_init go_quad_initl
 #define gnm_quad_value go_quad_valuel
 #define gnm_quad_add go_quad_addl
+#define gnm_quad_sub go_quad_subl
 #define gnm_quad_mul go_quad_mull
 #define gnm_quad_div go_quad_divl
 #define gnm_quad_mul12 go_quad_mul12l
+#define gnm_quad_sqrt go_quad_sqrtl
+#define gnm_quad_pow go_quad_powl
+#define gnm_quad_exp go_quad_expl
+#define gnm_quad_expm1 go_quad_expm1l
+#define gnm_quad_zero go_quad_zerol
+#define gnm_quad_one go_quad_onel
+#define gnm_quad_pi go_quad_pil
+#define gnm_quad_e go_quad_el
+#define gnm_quad_sqrt2 go_quad_sqrt2l
 #define GnmAccumulator GOAccumulatorl
 #define gnm_accumulator_start go_accumulator_startl
 #define gnm_accumulator_end go_accumulator_endl
@@ -144,7 +142,6 @@ typedef double gnm_float;
 #define gnm_atan2 atan2
 #define gnm_atanh atanh
 #define gnm_ceil ceil
-#define gnm_cos cos
 #define gnm_cosh cosh
 #define gnm_erf erf
 #define gnm_erfc erfc
@@ -176,13 +173,16 @@ typedef double gnm_float;
 #define gnm_pow10 go_pow10
 #define gnm_pow2 go_pow2
 #define gnm_render_general go_render_general
-#define gnm_sin sin
 #define gnm_sinh sinh
 #define gnm_sqrt sqrt
 #define gnm_strto go_strtod
 #define gnm_sub_epsilon go_sub_epsilon
-#define gnm_tan tan
 #define gnm_tanh tanh
+#ifndef GNM_REDUCES_TRIG_RANGE
+#define gnm_sin sin
+#define gnm_cos cos
+#define gnm_tan tan
+#endif
 
 #define GNM_FORMAT_e	"e"
 #define GNM_FORMAT_E	"E"
@@ -205,9 +205,19 @@ typedef double gnm_float;
 #define gnm_quad_init go_quad_init
 #define gnm_quad_value go_quad_value
 #define gnm_quad_add go_quad_add
+#define gnm_quad_sub go_quad_sub
 #define gnm_quad_mul go_quad_mul
 #define gnm_quad_div go_quad_div
 #define gnm_quad_mul12 go_quad_mul12
+#define gnm_quad_sqrt go_quad_sqrt
+#define gnm_quad_pow go_quad_pow
+#define gnm_quad_exp go_quad_exp
+#define gnm_quad_expm1 go_quad_expm1
+#define gnm_quad_zero go_quad_zero
+#define gnm_quad_one go_quad_one
+#define gnm_quad_pi go_quad_pi
+#define gnm_quad_e go_quad_e
+#define gnm_quad_sqrt2 go_quad_sqrt2
 #define GnmAccumulator GOAccumulator
 #define gnm_accumulator_start go_accumulator_start
 #define gnm_accumulator_end go_accumulator_end
@@ -219,6 +229,13 @@ typedef double gnm_float;
 
 #endif
 
+#ifdef GNM_REDUCES_TRIG_RANGE
+gnm_float gnm_sin (gnm_float x);
+gnm_float gnm_cos (gnm_float x);
+gnm_float gnm_tan (gnm_float x);
+#endif
+
+
 G_END_DECLS
 
 #endif /* _GNM_NUMBERS_H_ */
