@@ -28,7 +28,7 @@ char const *cellref_parse	(GnmCellRef *out, GnmSheetSize const *ss,
 
 void        rangeref_as_string  (GnmConventionsOut *out,
 				 GnmRangeRef const *ref);
-char const *rangeref_parse	(GnmRangeRef *res, char const *in,
+char const *rangeref_parse	(GnmRangeRef *res, char const *start,
 				 GnmParsePos const *pp,
 				 GnmConventions const *convs);
 				 /* GError **err); */
@@ -80,7 +80,9 @@ typedef struct {
 	gsize start, end;
 	int token;
 } GnmLexerItem;
+GType       gnm_lexer_item_get_type (void); /* Boxed type */
 
+GType       gnm_parse_error_get_type (void); /* Boxed type */
 GnmParseError *parse_error_init (GnmParseError *pe);
 void        parse_error_free (GnmParseError *pe);
 
@@ -200,6 +202,7 @@ struct _GnmConventions {
 					       char const *name);
 	} output;
 };
+GType           gnm_conventions_get_type (void);
 GnmConventions *gnm_conventions_new	 (void);
 GnmConventions *gnm_conventions_new_full (unsigned size);
 
@@ -233,7 +236,7 @@ void	    parse_text_value_or_expr (GnmParsePos const *pos,
 				      GnmValue **val,
 				      GnmExprTop const **texpr);
 
-GString	*gnm_expr_conv_quote (GnmConventions const *conv, char const *str);
+GString	*gnm_expr_conv_quote (GnmConventions const *convs, char const *str);
 
 G_END_DECLS
 
