@@ -29,6 +29,8 @@
 #include "sheet-object-graph.h"
 
 #include <goffice/goffice.h>
+#include <gsf/gsf-doc-meta-data.h>
+#include <gsf/gsf-meta-names.h>
 
 #include <glib/gi18n-lib.h>
 #include <string.h>
@@ -1362,10 +1364,7 @@ print_info_get_page_setup (PrintInformation *pi)
 	g_return_val_if_fail (pi != NULL, NULL);
 	print_info_load_defaults (pi);
 
-	if (pi->page_setup)
-		return pi->page_setup;
-	else
-		return NULL;
+	return pi->page_setup;
 }
 
 /**
