@@ -57,7 +57,6 @@ sv_selection_calc_simplification (SheetView const *sv)
 			      sv->selections->data != NULL,
 			      sv->selections);
 
-	ptr = sv->selections->next;
 	r_rm = sv->selections->data;
 
 	for (ptr = sv->selections->next; ptr != NULL; ptr = ptr->next) {
@@ -153,7 +152,6 @@ sv_is_range_selected (SheetView const *sv, GnmRange const *r)
 
 /**
  * sv_is_full_range_selected:
- *
  * @sv:
  * @r:
  *
@@ -215,7 +213,7 @@ sv_is_colrow_selected (SheetView const *sv, int colrow, gboolean is_col)
 }
 
 /**
- * sv_is_full_colrow_selected
+ * sv_is_full_colrow_selected:
  * @sv:
  * @is_cols:
  * @index:
@@ -289,7 +287,7 @@ sv_selection_col_type (SheetView const *sv, int col)
 /**
  * sv_selection_row_type:
  * @sv:
- * @col:
+ * @row:
  *
  * Returns: How much of column @col is selected in @sv.
  **/
@@ -390,9 +388,9 @@ sv_menu_enable_insert (SheetView *sv, gboolean col, gboolean row)
 }
 
 /**
- * selection_first_range
+ * selection_first_range:
  * @sv: The #SheetView whose selection we are testing.
- * @cc: The calling context to report errors to (GUI or corba)
+ * @cc: The command context to report errors to
  * @cmd_name: A string naming the operation requiring a single range.
  *
  * Returns the first range, if a control is supplied it displays an error if
@@ -425,7 +423,6 @@ selection_first_range (SheetView const *sv,
 
 /**
  * sv_selection_extend_to:
- *
  * @sv: the sheet
  * @col:   column that gets covered (negative indicates all cols)
  * @row:   row that gets covered (negative indicates all rows)
@@ -719,7 +716,7 @@ sv_selection_add_pos (SheetView *sv, int col, int row, GnmSelectionMode mode)
 }
 
 /**
- * sv_selection_free
+ * sv_selection_free:
  * @sv: #SheetView
  *
  * Releases the selection associated with @sv
@@ -736,7 +733,7 @@ sv_selection_free (SheetView *sv)
 }
 
 /**
- * sv_selection_simplified_free
+ * sv_selection_simplified_free:
  * @sv: #SheetView
  *
  * Releases the simplified selection associated with @sv
@@ -1231,7 +1228,7 @@ sheet_selection_is_allowed (Sheet const *sheet, GnmCellPos const *pos)
 		return sheet->protected_allow.select_unlocked_cells;
 }
 
-/**
+/*
  * walk_boundaries: Iterates through a region by row then column.
  * @sv: The sheet being iterated in
  * @bound: The bounding range
@@ -1241,7 +1238,7 @@ sheet_selection_is_allowed (Sheet const *sheet, GnmCellPos const *pos)
  * @res: The result.
  *
  * Returns: TRUE if the cursor leaves the boundary region.
- **/
+ */
 static gboolean
 walk_boundaries (SheetView const *sv, GnmRange const * const bound,
 		 gboolean const forward, gboolean const horizontal,
