@@ -816,7 +816,7 @@ sheet_style_shutdown (Sheet *sheet)
 
 /**
  * sheet_style_set_auto_pattern_color:
- * @sheet:         The sheet
+ * @sheet: The sheet
  * @grid_color: The color
  *
  * Set the color for rendering auto colored patterns in this sheet.
@@ -2787,6 +2787,19 @@ merge_horizontal_stripes (ISL *data)
 	}
 }
 
+static int
+by_col_row (GnmStyleRegion **a, GnmStyleRegion **b)
+{
+	int d;
+
+	d = (*a)->range.start.col - (*b)->range.start.col;
+	if (d)
+		return d;
+
+	d = (*a)->range.start.row - (*b)->range.start.row;
+	return d;
+}
+
 static GnmStyleList *
 internal_style_list (Sheet const *sheet, GnmRange const *r,
 		     gboolean (*style_equal) (GnmStyle const *a, GnmStyle const *b),
@@ -2826,6 +2839,17 @@ internal_style_list (Sheet const *sheet, GnmRange const *r,
 	if (data.style_filter ? (data.area > sheet_area) : (data.area != sheet_area))
 		g_warning ("Strange size issue in internal_style_list");
 
+	/*
+	 * Simple, fast optimization first.  For the file underlying
+	 * bug 699045 this brings down 332688 entries to just 86.
+	 */
+	if (data.accum->len >= 2) {
+		g_ptr_array_sort (data.accum, (GCompareFunc)by_col_row);
+		for (ui = data.accum->len - 1; ui > 0; ui--) {
+			try_merge_pair (&data, ui - 1, ui);
+		}
+	}
+
 	/* Populate hashes.  */
 	for (ui = 0; ui < data.accum->len; ui++) {
 		GnmStyleRegion *sr = g_ptr_array_index (data.accum, ui);
@@ -2954,11 +2978,11 @@ style_validation_filter (GnmStyle const *style)
 
 /**
  * sheet_style_collect_validations:
- * @sheet:
- * @r:
+ * @sheet: the to trawl
+ * @r: (allow-none): range to restrict to
  *
- * Returns: (transfer full): a list of areas with validation, Caller is
- * responsible for freeing.
+ * Returns: (transfer full): a list of areas with validation or input
+ * message.
  **/
 GnmStyleList *
 sheet_style_collect_validations (Sheet const *sheet, GnmRange const *r)
@@ -3133,6 +3157,55 @@ sheet_style_range_foreach (Sheet const *sheet, GnmRange const *r,
 
 /* ------------------------------------------------------------------------- */
 
+static void
+cell_tile_dump (CellTile **tile, int level, CellTileOptimize *data,
+		int ccol, int crow)
+{
+	CellTileType type;
+	int const w = tile_widths[level];
+	int const h = tile_heights[level];
+	GnmRange rng;
+	const char *indent = "";
+
+	type = (*tile)->type;
+
+	range_init (&rng,
+		    ccol, crow,
+		    MIN (ccol + tile_widths[level + 1] - 1,
+			 data->ss->max_cols - 1),
+		    MIN (crow + tile_heights[level + 1] - 1,
+			 data->ss->max_rows - 1));
+
+	g_printerr ("%s%s: type %s\n",
+		    indent,
+		    range_as_string (&rng),
+		    tile_type_str[type]);
+
+	if (type == TILE_PTR_MATRIX) {
+		int i;
+
+		for (i = 0; i < TILE_SIZE_COL * TILE_SIZE_ROW; i++) {
+			CellTile **subtile = (*tile)->ptr_matrix.ptr + i;
+			int c = i % TILE_SIZE_COL;
+			int r = i / TILE_SIZE_COL;
+			cell_tile_dump (subtile, level - 1, data,
+					ccol + w * c,
+					crow + h * r);
+		}
+	} else {
+		int i;
+
+		for (i = 0; i < tile_size[type]; i++) {
+			g_printerr ("%s: %d %p\n",
+				    indent,
+				    i,
+				    (*tile)->style_any.style[i]);
+		}
+	}
+}
+
+/* ------------------------------------------------------------------------- */
+
 static void
 cell_tile_optimize (CellTile **tile, int level, CellTileOptimize *data,
 		    int ccol, int crow)
@@ -3364,8 +3437,12 @@ sheet_style_optimize (Sheet *sheet)
 	data.ss = gnm_sheet_get_size (sheet);
 	data.recursion = TRUE;
 
-	if (debug_style_optimize)
+	if (debug_style_optimize) {
 		g_printerr ("Optimizing %s\n", sheet->name_unquoted);
+		cell_tile_dump (&sheet->style_data->styles,
+				sheet->tile_top_level, &data,
+				0, 0);
+	}
 
 	verify = gnm_debug_flag ("style-optimize-verify");
 	pre = verify ? sample_styles (sheet) : NULL;
