@@ -25,6 +25,7 @@
 #include <glib/gi18n-lib.h>
 #include "gnumeric.h"
 #include "stf.h"
+#include "stf-export.h"
 
 #include <goffice/goffice.h>
 #include "cell.h"
@@ -84,7 +85,7 @@ stf_warning (GOIOContext *context, char const *msg)
 
 /*
  * stf_open_and_read:
- * @filename : name of the file to open&read
+ * @filename: name of the file to open&read
  *
  * Will open filename, read the file into a g_alloced memory buffer
  *
@@ -211,11 +212,11 @@ resize_columns (Sheet *sheet)
 
 /*
  * stf_read_workbook:
- * @fo       : file opener
- * @enc      : encoding of file
- * @context  : command context
- * @book     : workbook
- * @input    : file to read from+convert
+ * @fo: file opener
+ * @enc: encoding of file
+ * @context: command context
+ * @book: workbook
+ * @input: file to read from+convert
  *
  * Main routine, handles importing a file including all dialog mumbo-jumbo
  */
@@ -229,9 +230,10 @@ stf_read_workbook (G_GNUC_UNUSED GOFileOpener const *fo,  gchar const *enc,
 	size_t data_len;
 	WorkbookView *wbv = WORKBOOK_VIEW (view);
 
-	/* FIXME : how to do this cleanly ? */
-	if (!IS_WBC_GTK (context->impl))
+	if (!IS_WBC_GTK (context->impl)) {
+		go_io_error_string (context, _("This importer can only be used with a GUI."));
 		return;
+	}
 
 	name = g_path_get_basename (gsf_input_name (input));
 	nameutf8 = g_filename_to_utf8 (name, -1, NULL, NULL, NULL);
@@ -413,11 +415,11 @@ clear_stray_NULs (GOIOContext *context, GString *utf8data)
 
 /*
  * stf_read_workbook_auto_csvtab:
- * @fo       : file opener
- * @enc      : optional encoding
- * @context  : command context
- * @book     : workbook
- * @input    : file to read from+convert
+ * @fo: file opener
+ * @enc: optional encoding
+ * @context: command context
+ * @book: workbook
+ * @input: file to read from+convert
  *
  * Attempt to auto-detect CSV or tab-delimited file
  */
@@ -654,10 +656,12 @@ stf_init (void)
 		_("Text import (configurable)"),
 		NULL, mimes_txt,
 		NULL, stf_read_workbook);
+	g_object_set (G_OBJECT (opener), "interactive-only", TRUE, NULL);
 	go_file_opener_register (opener, 0);
 	g_object_unref (opener);
 
 	saver = gnm_stf_file_saver_create ("Gnumeric_stf:stf_assistant");
+	/* Unlike the opener, the saver doesn't require interaction.  */
 	go_file_saver_register (saver);
 	g_object_unref (saver);
 
