@@ -75,7 +75,7 @@ wbcg_auto_complete_destroy (WBCGtk *wbcg)
 	}
 
 	if (wbcg->auto_complete != NULL) {
-		g_object_unref (G_OBJECT (wbcg->auto_complete));
+		g_object_unref (wbcg->auto_complete);
 		wbcg->auto_complete = NULL;
 	}
 
@@ -805,7 +805,6 @@ cb_warn_toggled (GtkToggleButton *button, gboolean *b)
 
 /**
  * wbcg_edit_start:
- *
  * @wbcg:       The workbook to be edited.
  * @blankp:   If true, erase current cell contents first.  If false, leave the
  *            contents alone.
@@ -1063,7 +1062,7 @@ wbcg_insert_object_clear (WBCGtk *wbcg)
 		int i, npages;
 		SheetControlGUI *scg;
 
-		g_object_unref (G_OBJECT (wbcg->new_object));
+		g_object_unref (wbcg->new_object);
 		wbcg->new_object = NULL;
 
 		npages = wbcg_get_n_scg (wbcg);
