@@ -86,7 +86,7 @@ struct _WBCGtk {
 	/* Autosave */
         gboolean   autosave_prompt;
         gint       autosave_time;
-        gint       autosave_timer;
+        guint      autosave_timer;
 
 	PangoFontDescription *font_desc;
 
@@ -113,7 +113,8 @@ struct _WBCGtk {
 	GOActionComboStack	*undo_haction, *redo_haction;
 	GtkAction		*undo_vaction, *redo_vaction;
 	GOActionComboColor	*fore_color, *back_color;
-	GOActionComboText	*font_name, *font_size, *zoom_haction;
+	GtkAction               *font_name_haction, *font_name_vaction;
+	GOActionComboText	*zoom_haction;
 	GtkAction               *zoom_vaction;
 	GOActionComboPixmaps	*borders, *halignment, *valignment;
 	struct {
